==> qtwebengine-everywhere-opensource-src-6.5.4.zip: qtwebengine-everywhere-src-6.5.4/src/3rdparty/chromium/chrome/browser/ui/webui/commerce/shopping_list_context_menu_controller.h <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_WEBUI_COMMERCE_SHOPPING_LIST_CONTEXT_MENU_CONTROLLER_H_
#define CHROME_BROWSER_UI_WEBUI_COMMERCE_SHOPPING_LIST_CONTEXT_MENU_CONTROLLER_H_

#include "base/memory/raw_ptr.h"

namespace bookmarks {
class BookmarkModel;
class BookmarkNode;
}  // namespace bookmarks

namespace ui {
class SimpleMenuModel;
}  // namespace ui

namespace commerce {

class ShoppingService;

// Helper class for shopping-related items in side panel context menu. This is
// created when the context menu is opened and destroyed when the side panel is
// closed.
class ShoppingListContextMenuController {
 public:
  ShoppingListContextMenuController(
      bookmarks::BookmarkModel* bookmark_model,
      ShoppingService* shopping_service,
      const bookmarks::BookmarkNode* bookmark_node,
      ui::SimpleMenuModel* menu_model);
  ShoppingListContextMenuController(const ShoppingListContextMenuController&) =
      delete;
  ShoppingListContextMenuController& operator=(
      const ShoppingListContextMenuController&) = delete;
  ~ShoppingListContextMenuController() = default;

  // Add menu item that will track or untrack price for this product bookmark
  // based on whether it's been tracked now.
  void AddPriceTrackingItemForBookmark();
  // Execute the context menu action represented by |command_id|.
  bool ExecuteCommand(int command_id);

 private:
  raw_ptr<bookmarks::BookmarkModel> bookmark_model_;
  raw_ptr<ShoppingService> shopping_service_;
  const bookmarks::BookmarkNode* bookmark_node_;
  raw_ptr<ui::SimpleMenuModel> menu_model_;
};

}  // namespace commerce

#endif  // CHROME_BROWSER_UI_WEBUI_COMMERCE_SHOPPING_LIST_CONTEXT_MENU_CONTROLLER_H_

==> qtwebengine-everywhere-opensource-src-6.5.7.zip: qtwebengine-everywhere-src-6.5.7/src/3rdparty/chromium/chrome/browser/ui/webui/commerce/shopping_list_context_menu_controller.h <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_WEBUI_COMMERCE_SHOPPING_LIST_CONTEXT_MENU_CONTROLLER_H_
#define CHROME_BROWSER_UI_WEBUI_COMMERCE_SHOPPING_LIST_CONTEXT_MENU_CONTROLLER_H_

#include "base/memory/raw_ptr.h"

namespace bookmarks {
class BookmarkModel;
class BookmarkNode;
}  // namespace bookmarks

namespace ui {
class SimpleMenuModel;
}  // namespace ui

namespace commerce {

class ShoppingService;
class ShoppingListHandler;

// Helper class for shopping-related items in side panel context menu. This
// class is created and owned by BookmarksSidePanelUI so that it can be used for
// context menu controlling in the bookmark side panel.
class ShoppingListContextMenuController {
 public:
  ShoppingListContextMenuController(bookmarks::BookmarkModel* bookmark_model,
                                    ShoppingService* shopping_service,
                                    ShoppingListHandler* shopping_list_hander);
  ShoppingListContextMenuController(const ShoppingListContextMenuController&) =
      delete;
  ShoppingListContextMenuController& operator=(
      const ShoppingListContextMenuController&) = delete;
  ~ShoppingListContextMenuController() = default;

  // Add menu item that will track or untrack price for this product bookmark
  // based on whether it's been tracked now.
  void AddPriceTrackingItemForBookmark(ui::SimpleMenuModel* menu_model,
                                       const bookmarks::BookmarkNode* node);
  // Execute the context menu action represented by |command_id|.
  bool ExecuteCommand(int command_id, const bookmarks::BookmarkNode* node);

 private:
  raw_ptr<bookmarks::BookmarkModel> bookmark_model_;
  raw_ptr<ShoppingService> shopping_service_;
  raw_ptr<ShoppingListHandler, DanglingUntriaged> shopping_list_hander_;
};

}  // namespace commerce

#endif  // CHROME_BROWSER_UI_WEBUI_COMMERCE_SHOPPING_LIST_CONTEXT_MENU_CONTROLLER_H_
